/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FLANGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FLANGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FLANGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FLANGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FLANGR::Heavy_WSTD_FLANGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_p9fmoV6A);
  numBytes += sPhasor_k_init(&sPhasor_QXcjPkSE, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_M5QleMJ0);
  numBytes += sRPole_init(&sRPole_qQRrEzf4);
  numBytes += sRPole_init(&sRPole_DuJsXZy6);
  numBytes += sTabhead_init(&sTabhead_GDPu397w, &hTable_vYDTqcY9);
  numBytes += sTabread_init(&sTabread_UlfAYXC7, &hTable_vYDTqcY9, false);
  numBytes += sTabread_init(&sTabread_XPC2xqSY, &hTable_vYDTqcY9, false);
  numBytes += sLine_init(&sLine_KNtMVRpZ);
  numBytes += sTabhead_init(&sTabhead_IAbdeH4Y, &hTable_sdmFXiw7);
  numBytes += sTabread_init(&sTabread_VE8M5vdA, &hTable_sdmFXiw7, false);
  numBytes += sTabread_init(&sTabread_uACPbrjD, &hTable_sdmFXiw7, false);
  numBytes += sLine_init(&sLine_GQryaRkg);
  numBytes += sTabwrite_init(&sTabwrite_NGSETWdX, &hTable_sdmFXiw7);
  numBytes += sTabwrite_init(&sTabwrite_RL6aqun7, &hTable_vYDTqcY9);
  numBytes += cVar_init_f(&cVar_N0eECB7Y, 0.0f);
  numBytes += cVar_init_f(&cVar_Ft25ZwQB, 0.0f);
  numBytes += cVar_init_f(&cVar_PCSN1RAS, 0.0f);
  numBytes += cVar_init_f(&cVar_0QFZUvCJ, 0.0f);
  numBytes += cVar_init_s(&cVar_dbh2Rskt, "del-1010-flanger-l");
  numBytes += sVarf_init(&sVarf_CflO10yK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_adtq9W2H, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2aIOkE5O, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_1bznRAtL, "del-1010-flanger-r");
  numBytes += sVarf_init(&sVarf_moXZyNIH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jggObU43, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ma8qTum4, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_aXH4Vbk8, 0.0f);
  numBytes += cDelay_init(this, &cDelay_h72XzGrY, 0.0f);
  numBytes += hTable_init(&hTable_sdmFXiw7, 256);
  numBytes += cDelay_init(this, &cDelay_n51RdxGu, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ScQga8it, 0.0f);
  numBytes += hTable_init(&hTable_vYDTqcY9, 256);
  numBytes += cVar_init_f(&cVar_j5pbCpxx, 14.0f);
  numBytes += cBinop_init(&cBinop_8G6EfzKU, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_LAjE79lN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_66RP0Wn6, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_rWXvtan7, 14.0f);
  numBytes += cBinop_init(&cBinop_dYz5sUyY, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_SZSF2D0O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_al8yNc2C, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_GKnR2qZj, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_LlkY6QSU, 1, -1);
  numBytes += cVar_init_f(&cVar_5a2Qp2h6, 0.2f);
  numBytes += cSlice_init(&cSlice_Sh0WkS0b, 1, -1);
  numBytes += cVar_init_f(&cVar_V1cUBpcZ, 0.0f);
  numBytes += cSlice_init(&cSlice_xB1x6F10, 1, -1);
  numBytes += cVar_init_f(&cVar_8PfdXK35, 2.0f);
  numBytes += cSlice_init(&cSlice_Wx7jdtBu, 1, -1);
  numBytes += cVar_init_f(&cVar_fnTKe7s9, 0.5f);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FLANGR::~Heavy_WSTD_FLANGR() {
  hTable_free(&hTable_sdmFXiw7);
  hTable_free(&hTable_vYDTqcY9);
}

HvTable *Heavy_WSTD_FLANGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x297C7484: return &hTable_sdmFXiw7; // del-1010-flanger-r
    case 0x7DBB345F: return &hTable_vYDTqcY9; // del-1010-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FLANGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hdO54E5w_sendMessage);
      break;
    }
    case 0x20BB009B: { // Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5tO4O8Ok_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s5w9lWJZ_sendMessage);
      break;
    }
    case 0x9A248230: { // Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OhSemleZ_sendMessage);
      break;
    }
    case 0xD6AF3228: { // 1010-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_asQDBLXi_sendMessage);
      break;
    }
    case 0x68077D82: { // 1010-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XtDKPmX5_sendMessage);
      break;
    }
    case 0x36F9AB4: { // 1010-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2vZsSHET_sendMessage);
      break;
    }
    case 0xF709FF0E: { // 1010-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m7PRFzAW_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_M8HgjlR8_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FLANGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Intensity";
        info->hash = 0x20BB009B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Speed";
        info->hash = 0x9A248230;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FLANGR::cVar_N0eECB7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gwwrgro2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_Ft25ZwQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nIWl5CPx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_PCSN1RAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jijyYTcw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_0QFZUvCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ydjmQf5a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_kL0FGqNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_t2rQO78I_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_t2rQO78I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_QXcjPkSE, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_Y1abazsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_naYtTDNd_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_naYtTDNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_1vcqUcNf_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_dbh2Rskt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fIfhVn7A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_S1OSve99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_4pgyqvoO_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CflO10yK, m);
}

void Heavy_WSTD_FLANGR::cBinop_1vcqUcNf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_adtq9W2H, m);
}

void Heavy_WSTD_FLANGR::cMsg_fIfhVn7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_S1OSve99_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_4pgyqvoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2aIOkE5O, m);
}

void Heavy_WSTD_FLANGR::cMsg_xriFDvhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0jEZEOKB_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_0jEZEOKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_GknnMJlL_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_1bznRAtL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b4ANwRuO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_KW6eh326_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Wl4r5tdR_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_moXZyNIH, m);
}

void Heavy_WSTD_FLANGR::cBinop_GknnMJlL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_jggObU43, m);
}

void Heavy_WSTD_FLANGR::cMsg_b4ANwRuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KW6eh326_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Wl4r5tdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ma8qTum4, m);
}

void Heavy_WSTD_FLANGR::cBinop_NkSjRfbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_aJ9sk12H_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_aJ9sk12H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Y3HSMicO_sendMessage);
}

void Heavy_WSTD_FLANGR::cUnop_XbpzooC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_raW2UET9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cUnop_lct0M3o3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zbIr7BcF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_Y3HSMicO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_BWrCdQlX_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_BWrCdQlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zXFF9Ad8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_THC03Tn5_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_THC03Tn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bS6R77cA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cCast_zXFF9Ad8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9gP5KGbT_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_9gP5KGbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_njzQ6BEf_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_bS6R77cA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_aGd4jbyr_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_aGd4jbyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tJxnRnjU_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_njzQ6BEf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_XbpzooC4_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_tJxnRnjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_lct0M3o3_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_g3PL4w2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_yVeUnPPv_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_yVeUnPPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qNG4Qu19_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_crGDVTK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kqemlIto_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_kqemlIto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_nPiB9vGz_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_aXH4Vbk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aXH4Vbk8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h72XzGrY, 0, m, &cDelay_h72XzGrY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aXH4Vbk8, 0, m, &cDelay_aXH4Vbk8_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_NGSETWdX, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_h72XzGrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_h72XzGrY, m);
  cMsg_ttikQ7r9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_TyrNVxdl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_zORF6TOw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_YOzlM1lr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DQns45Jt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_sdmFXiw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YXsMsn26_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aXH4Vbk8, 2, m, &cDelay_aXH4Vbk8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Pqqwg3Fc_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_DQns45Jt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_sdmFXiw7, 0, m, &hTable_sdmFXiw7_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_nPiB9vGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_YOzlM1lr_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_ttikQ7r9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_sdmFXiw7, 0, m, &hTable_sdmFXiw7_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_Pqqwg3Fc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_aXH4Vbk8, 0, m, &cDelay_aXH4Vbk8_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_YXsMsn26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_h72XzGrY, 2, m, &cDelay_h72XzGrY_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_zORF6TOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_NGSETWdX, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_Wzbrs5a4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fS2ZmZwN_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_fS2ZmZwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_8VKA9aJA_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_n51RdxGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_n51RdxGu, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ScQga8it, 0, m, &cDelay_ScQga8it_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_n51RdxGu, 0, m, &cDelay_n51RdxGu_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_RL6aqun7, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_ScQga8it_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ScQga8it, m);
  cMsg_8YTAD2zP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_aNHrRKbh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_N0PpqzoP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_2iRINlPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bsFrl63r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_vYDTqcY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x6wsSHyX_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_n51RdxGu, 2, m, &cDelay_n51RdxGu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VfdvjRVg_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_bsFrl63r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_vYDTqcY9, 0, m, &hTable_vYDTqcY9_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_8VKA9aJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_2iRINlPs_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_8YTAD2zP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_vYDTqcY9, 0, m, &hTable_vYDTqcY9_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_VfdvjRVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_n51RdxGu, 0, m, &cDelay_n51RdxGu_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_x6wsSHyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_ScQga8it, 2, m, &cDelay_ScQga8it_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_N0PpqzoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_RL6aqun7, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cVar_j5pbCpxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8G6EfzKU, HV_BINOP_MULTIPLY, 0, m, &cBinop_8G6EfzKU_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_0WcrnM6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PoSAHbDx_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_PoSAHbDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2SrTtUtv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_8G6EfzKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_tqVpyeLE_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_ZQRSOWye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8G6EfzKU, HV_BINOP_MULTIPLY, 1, m, &cBinop_8G6EfzKU_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_2SrTtUtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZQRSOWye_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_tqVpyeLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_NfvYlZM2_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_NfvYlZM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_QAUOuODk_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_66RP0Wn6, m);
}

void Heavy_WSTD_FLANGR::cBinop_QAUOuODk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LAjE79lN, m);
}

void Heavy_WSTD_FLANGR::cVar_rWXvtan7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dYz5sUyY, HV_BINOP_MULTIPLY, 0, m, &cBinop_dYz5sUyY_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_Zia5V0UM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sqaZYrDo_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_sqaZYrDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9sumW765_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_dYz5sUyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qizgyf8J_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_bj1TkjLZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dYz5sUyY, HV_BINOP_MULTIPLY, 1, m, &cBinop_dYz5sUyY_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_9sumW765_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bj1TkjLZ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_qizgyf8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fPIpXQXc_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_fPIpXQXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1p4qwNrj_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_al8yNc2C, m);
}

void Heavy_WSTD_FLANGR::cBinop_1p4qwNrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_SZSF2D0O, m);
}

void Heavy_WSTD_FLANGR::cMsg_qNG4Qu19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M5QleMJ0, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cUnop_3e0xpurJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_M1KLoZQY_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_1DbYtV6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_3e0xpurJ_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_Xp07MMuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_90wNuj21_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_BjqgldU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_RLnbs5HR_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_RLnbs5HR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GKnR2qZj, HV_BINOP_MULTIPLY, 1, m, &cBinop_GKnR2qZj_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_90wNuj21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_BjqgldU5_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_GKnR2qZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1Xy8DQl3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_M1KLoZQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GKnR2qZj, HV_BINOP_MULTIPLY, 0, m, &cBinop_GKnR2qZj_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_1Xy8DQl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GQryaRkg, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_w0whmrJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_a4iw7qnY_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_a4iw7qnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xp07MMuF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1DbYtV6l_sendMessage);
}

void Heavy_WSTD_FLANGR::cSwitchcase_iCASjSMx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LlkY6QSU, 0, m, &cSlice_LlkY6QSU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cIJmvdNR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_LlkY6QSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_82IRAIcy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_82IRAIcy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_5a2Qp2h6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_82IRAIcy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_82IRAIcy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XtDKPmX5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_cIJmvdNR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Sh0WkS0b, 0, m, &cSlice_Sh0WkS0b_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xQFkrVwb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_Sh0WkS0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Z1DK7Oxe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Z1DK7Oxe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_V1cUBpcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Z1DK7Oxe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_Z1DK7Oxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_asQDBLXi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_xQFkrVwb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xB1x6F10, 0, m, &cSlice_xB1x6F10_sendMessage);
      break;
    }
    default: {
      cSwitchcase_j7jMuwhi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_xB1x6F10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_epO0yIan_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_epO0yIan_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_8PfdXK35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_epO0yIan_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_epO0yIan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_m7PRFzAW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_j7jMuwhi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Wx7jdtBu, 0, m, &cSlice_Wx7jdtBu_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_Wx7jdtBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Zo1aVwin_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Zo1aVwin_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_fnTKe7s9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Zo1aVwin_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_Zo1aVwin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2vZsSHET_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_raW2UET9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KNtMVRpZ, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_zbIr7BcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_p9fmoV6A, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_ydjmQf5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_iCASjSMx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_Gwwrgro2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_iCASjSMx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_nIWl5CPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_iCASjSMx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_jijyYTcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_iCASjSMx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_x2asFb7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0QFZUvCJ, 0, m, &cVar_0QFZUvCJ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_c4xYXr4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N0eECB7Y, 0, m, &cVar_N0eECB7Y_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_nUpvDbgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PCSN1RAS, 0, m, &cVar_PCSN1RAS_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_m7PRFzAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_kL0FGqNo_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_asQDBLXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_w0whmrJq_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_M8HgjlR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0WcrnM6s_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_j5pbCpxx, 0, m, &cVar_j5pbCpxx_sendMessage);
  cMsg_Zia5V0UM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_rWXvtan7, 0, m, &cVar_rWXvtan7_sendMessage);
  cMsg_crGDVTK6_sendMessage(_c, 0, m);
  cMsg_Wzbrs5a4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5a2Qp2h6, 0, m, &cVar_5a2Qp2h6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_V1cUBpcZ, 0, m, &cVar_V1cUBpcZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8PfdXK35, 0, m, &cVar_8PfdXK35_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fnTKe7s9, 0, m, &cVar_fnTKe7s9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dbh2Rskt, 0, m, &cVar_dbh2Rskt_sendMessage);
  cMsg_Y1abazsx_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1bznRAtL, 0, m, &cVar_1bznRAtL_sendMessage);
  cMsg_xriFDvhS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cReceive_2vZsSHET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_NkSjRfbq_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_XtDKPmX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_g3PL4w2N_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_OhSemleZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ft25ZwQB, 0, m, &cVar_Ft25ZwQB_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_s5w9lWJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_x2asFb7g_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_5tO4O8Ok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_nUpvDbgX_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_hdO54E5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_c4xYXr4i_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FLANGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_p9fmoV6A, VOf(Bf0));
    __hv_phasor_k_f(&sPhasor_QXcjPkSE, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_M5QleMJ0, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf3));
    __hv_varread_f(&sVarf_66RP0Wn6, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_LAjE79lN, VOf(Bf3));
    __hv_rpole_f(&sRPole_qQRrEzf4, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_al8yNc2C, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_SZSF2D0O, VOf(Bf4));
    __hv_rpole_f(&sRPole_DuJsXZy6, VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_tabhead_f(&sTabhead_GDPu397w, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_adtq9W2H, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_2aIOkE5O, VOf(Bf4));
    __hv_min_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_CflO10yK, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_lt_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_and_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_cast_fi(VIf(Bf5), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_UlfAYXC7, VIi(Bi1), VOf(Bf5));
    __hv_tabread_if(&sTabread_XPC2xqSY, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf5), VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_KNtMVRpZ, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf5));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_IAbdeH4Y, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_jggObU43, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Ma8qTum4, VOf(Bf3));
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_varread_f(&sVarf_moXZyNIH, VOf(Bf3));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf3), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_VE8M5vdA, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_uACPbrjD, VIi(Bi0), VOf(Bf3));
    __hv_sub_f(VIf(Bf7), VIf(Bf3), VOf(Bf7));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(I1), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_GQryaRkg, VOf(Bf0));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(I1), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_NGSETWdX, VIf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf0), VIf(I0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_RL6aqun7, VIf(Bf0));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf5), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FLANGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FLANGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
