/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
#define _HEAVY_CONTEXT_WSTD_FLANGR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlBinop.h"
#include "HvSignalRPole.h"
#include "HvControlCast.h"
#include "HvControlVar.h"
#include "HvControlSlice.h"
#include "HvSignalPhasor.h"
#include "HvMath.h"
#include "HvControlDelay.h"
#include "HvSignalTabread.h"
#include "HvTable.h"
#include "HvSignalTabwrite.h"
#include "HvSignalDel1.h"
#include "HvSignalVar.h"
#include "HvControlUnop.h"
#include "HvSignalLine.h"
#include "HvControlSystem.h"

class Heavy_WSTD_FLANGR : public HeavyContext {

 public:
  Heavy_WSTD_FLANGR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_FLANGR();

  const char *getName() override { return "WSTD_FLANGR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        FEEDBACK = 0x57157946, // Feedback
        INTENSITY = 0x20BB009B, // Intensity
        MIX = 0x97D46AC6, // Mix
        SPEED = 0x9A248230, // Speed
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_N0eECB7Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ft25ZwQB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PCSN1RAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0QFZUvCJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kL0FGqNo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t2rQO78I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y1abazsx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_naYtTDNd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dbh2Rskt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_S1OSve99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1vcqUcNf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fIfhVn7A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4pgyqvoO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xriFDvhS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0jEZEOKB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1bznRAtL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_KW6eh326_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GknnMJlL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b4ANwRuO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Wl4r5tdR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NkSjRfbq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aJ9sk12H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_XbpzooC4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_lct0M3o3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y3HSMicO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BWrCdQlX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_THC03Tn5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zXFF9Ad8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9gP5KGbT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bS6R77cA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aGd4jbyr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_njzQ6BEf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tJxnRnjU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g3PL4w2N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yVeUnPPv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_crGDVTK6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kqemlIto_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_aXH4Vbk8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_h72XzGrY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TyrNVxdl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_YOzlM1lr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_sdmFXiw7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DQns45Jt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nPiB9vGz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ttikQ7r9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Pqqwg3Fc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YXsMsn26_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zORF6TOw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Wzbrs5a4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fS2ZmZwN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_n51RdxGu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ScQga8it_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_aNHrRKbh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_2iRINlPs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_vYDTqcY9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bsFrl63r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8VKA9aJA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8YTAD2zP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VfdvjRVg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x6wsSHyX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N0PpqzoP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_j5pbCpxx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0WcrnM6s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_PoSAHbDx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8G6EfzKU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZQRSOWye_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2SrTtUtv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tqVpyeLE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NfvYlZM2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QAUOuODk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rWXvtan7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zia5V0UM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_sqaZYrDo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dYz5sUyY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bj1TkjLZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9sumW765_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qizgyf8J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fPIpXQXc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1p4qwNrj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qNG4Qu19_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3e0xpurJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1DbYtV6l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Xp07MMuF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BjqgldU5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RLnbs5HR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_90wNuj21_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GKnR2qZj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M1KLoZQY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1Xy8DQl3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w0whmrJq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a4iw7qnY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_iCASjSMx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_LlkY6QSU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5a2Qp2h6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_82IRAIcy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_cIJmvdNR_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Sh0WkS0b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_V1cUBpcZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Z1DK7Oxe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xQFkrVwb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_xB1x6F10_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8PfdXK35_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_epO0yIan_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_j7jMuwhi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Wx7jdtBu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fnTKe7s9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Zo1aVwin_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_raW2UET9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zbIr7BcF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ydjmQf5a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gwwrgro2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nIWl5CPx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jijyYTcw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x2asFb7g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c4xYXr4i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nUpvDbgX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_m7PRFzAW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_asQDBLXi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_M8HgjlR8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2vZsSHET_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XtDKPmX5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OhSemleZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_s5w9lWJZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5tO4O8Ok_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hdO54E5w_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_p9fmoV6A;
  SignalPhasor sPhasor_QXcjPkSE;
  SignalLine sLine_M5QleMJ0;
  SignalRPole sRPole_qQRrEzf4;
  SignalRPole sRPole_DuJsXZy6;
  SignalTabhead sTabhead_GDPu397w;
  SignalTabread sTabread_UlfAYXC7;
  SignalTabread sTabread_XPC2xqSY;
  SignalLine sLine_KNtMVRpZ;
  SignalTabhead sTabhead_IAbdeH4Y;
  SignalTabread sTabread_VE8M5vdA;
  SignalTabread sTabread_uACPbrjD;
  SignalLine sLine_GQryaRkg;
  SignalTabwrite sTabwrite_NGSETWdX;
  SignalTabwrite sTabwrite_RL6aqun7;
  ControlVar cVar_N0eECB7Y;
  ControlVar cVar_Ft25ZwQB;
  ControlVar cVar_PCSN1RAS;
  ControlVar cVar_0QFZUvCJ;
  ControlBinop cBinop_kL0FGqNo;
  ControlBinop cBinop_t2rQO78I;
  ControlVar cVar_dbh2Rskt;
  ControlBinop cBinop_1vcqUcNf;
  ControlBinop cBinop_4pgyqvoO;
  SignalVarf sVarf_CflO10yK;
  SignalVarf sVarf_adtq9W2H;
  SignalVarf sVarf_2aIOkE5O;
  ControlVar cVar_1bznRAtL;
  ControlBinop cBinop_GknnMJlL;
  ControlBinop cBinop_Wl4r5tdR;
  SignalVarf sVarf_moXZyNIH;
  SignalVarf sVarf_jggObU43;
  SignalVarf sVarf_Ma8qTum4;
  ControlBinop cBinop_NkSjRfbq;
  ControlBinop cBinop_aJ9sk12H;
  ControlBinop cBinop_Y3HSMicO;
  ControlBinop cBinop_BWrCdQlX;
  ControlBinop cBinop_9gP5KGbT;
  ControlBinop cBinop_aGd4jbyr;
  ControlBinop cBinop_njzQ6BEf;
  ControlBinop cBinop_tJxnRnjU;
  ControlBinop cBinop_g3PL4w2N;
  ControlBinop cBinop_yVeUnPPv;
  ControlDelay cDelay_aXH4Vbk8;
  ControlDelay cDelay_h72XzGrY;
  ControlBinop cBinop_YOzlM1lr;
  HvTable hTable_sdmFXiw7;
  ControlBinop cBinop_nPiB9vGz;
  ControlDelay cDelay_n51RdxGu;
  ControlDelay cDelay_ScQga8it;
  ControlBinop cBinop_2iRINlPs;
  HvTable hTable_vYDTqcY9;
  ControlBinop cBinop_8VKA9aJA;
  ControlVar cVar_j5pbCpxx;
  ControlBinop cBinop_8G6EfzKU;
  ControlBinop cBinop_ZQRSOWye;
  SignalVarf sVarf_LAjE79lN;
  ControlBinop cBinop_tqVpyeLE;
  ControlBinop cBinop_NfvYlZM2;
  ControlBinop cBinop_QAUOuODk;
  SignalVarf sVarf_66RP0Wn6;
  ControlVar cVar_rWXvtan7;
  ControlBinop cBinop_dYz5sUyY;
  ControlBinop cBinop_bj1TkjLZ;
  SignalVarf sVarf_SZSF2D0O;
  ControlBinop cBinop_qizgyf8J;
  ControlBinop cBinop_fPIpXQXc;
  ControlBinop cBinop_1p4qwNrj;
  SignalVarf sVarf_al8yNc2C;
  ControlBinop cBinop_BjqgldU5;
  ControlBinop cBinop_RLnbs5HR;
  ControlBinop cBinop_90wNuj21;
  ControlBinop cBinop_GKnR2qZj;
  ControlBinop cBinop_M1KLoZQY;
  ControlBinop cBinop_w0whmrJq;
  ControlBinop cBinop_a4iw7qnY;
  ControlSlice cSlice_LlkY6QSU;
  ControlVar cVar_5a2Qp2h6;
  ControlSlice cSlice_Sh0WkS0b;
  ControlVar cVar_V1cUBpcZ;
  ControlSlice cSlice_xB1x6F10;
  ControlVar cVar_8PfdXK35;
  ControlSlice cSlice_Wx7jdtBu;
  ControlVar cVar_fnTKe7s9;
  ControlBinop cBinop_x2asFb7g;
  ControlBinop cBinop_c4xYXr4i;
  ControlBinop cBinop_nUpvDbgX;
};

#endif // _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
